#[non_exhaustive]pub struct SentenceBreakOptions<'a> {
pub content_locale: Option<&'a LanguageIdentifier>,
pub invariant_options: SentenceBreakInvariantOptions,
}Expand description
Options to tailor sentence breaking behavior.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.content_locale: Option<&'a LanguageIdentifier>Content locale for sentence segmenter.
If you know the language of the text being segmented, provide it here in order to produce higher quality breakpoints.
invariant_options: SentenceBreakInvariantOptionsOptions independent of the locale